@@ -152,6 +152,8 @@ QVector<int> ServerTestPrivate::parseAuthenticationList(const QStringList &authe
             result << Transport::EnumAuthenticationType::GSSAPI;
         } else if (current == QLatin1String("ANONYMOUS")) {
             result << Transport::EnumAuthenticationType::ANONYMOUS;
+        } else if (current == QLatin1String("XOAUTH2")) {
+            result << Transport::EnumAuthenticationType::XOAUTH2;
         }
         // APOP is handled by handlePopConversation()
     }
@@ -175,10 +177,10 @@ void ServerTestPrivate::handleSMTPIMAPResponse(int type, const QString &text)
     }
 
     QStringList protocols;
-    protocols << QStringLiteral("LOGIN") << QStringLiteral("PLAIN")
-              << QStringLiteral("CRAM-MD5") << QStringLiteral("DIGEST-MD5")
-              << QStringLiteral("NTLM") << QStringLiteral("GSSAPI")
-              << QStringLiteral("ANONYMOUS");
+    protocols << QStringLiteral("XOAUTH2") << QStringLiteral("LOGIN")
+              << QStringLiteral("PLAIN") << QStringLiteral("CRAM-MD5")
+              << QStringLiteral("DIGEST-MD5") << QStringLiteral("NTLM")
+              << QStringLiteral("GSSAPI") << QStringLiteral("ANONYMOUS");
 
     QStringList results;
     for (int i = 0; i < protocols.count(); ++i) {
@@ -492,6 +494,14 @@ void ServerTestPrivate::slotReadSecure(const QString &text)
 
 void ServerTestPrivate::slotNormalNotPossible()
 {
+    if (testProtocol == SMTP_PROTOCOL && normalSocket->port() == SMTP_PORT) {
+        // For SMTP, fallback to port 25
+        normalSocket->setPort(SMTP_OLD_PORT);
+        normalSocket->reconnect();
+        normalSocketTimer->start(10000);
+        return;
+    }
+
     normalSocketTimer->stop();
     normalPossible = false;
     normalSocketFinished = true;
