@@ -22,9 +22,15 @@
 using namespace Akonadi;
 using namespace MailTransport;
 
-class SentBehaviourAttribute::Private
+class Q_DECL_HIDDEN SentBehaviourAttribute::Private
 {
 public:
+    Private()
+        : mBehaviour(SentBehaviourAttribute::MoveToDefaultSentCollection)
+        , mSilent(false)
+    {
+    }
+
     SentBehaviourAttribute::SentBehaviour mBehaviour;
     Akonadi::Collection mMoveToCollection;
     bool mSilent;
@@ -60,13 +66,13 @@ QByteArray SentBehaviourAttribute::serialized() const
 
     switch (d->mBehaviour) {
     case Delete:
-        out = "delete";
+        out = QByteArrayLiteral("delete");
         break;
     case MoveToCollection:
-        out = "moveTo" + QByteArray::number(d->mMoveToCollection.id());
+        out = QByteArrayLiteral("moveTo") + QByteArray::number(d->mMoveToCollection.id());
         break;
     case MoveToDefaultSentCollection:
-        out = "moveToDefault";
+        out = QByteArrayLiteral("moveToDefault");
         break;
     default:
         Q_ASSERT(false);
@@ -74,7 +80,7 @@ QByteArray SentBehaviourAttribute::serialized() const
     }
 
     if (d->mSilent) {
-        out += ",silent";
+        out += QByteArrayLiteral(",silent");
     }
 
     return out;
@@ -83,7 +89,7 @@ QByteArray SentBehaviourAttribute::serialized() const
 void SentBehaviourAttribute::deserialize(const QByteArray &data)
 {
     const QByteArrayList in = data.split(',');
-    Q_ASSERT(in.size() > 0);
+    Q_ASSERT(!in.isEmpty());
 
     const QByteArray attr0 = in[0];
     d->mMoveToCollection = Akonadi::Collection(-1);
@@ -91,7 +97,7 @@ void SentBehaviourAttribute::deserialize(const QByteArray &data)
         d->mBehaviour = Delete;
     } else if (attr0 == "moveToDefault") {
         d->mBehaviour = MoveToDefaultSentCollection;
-    } else if (attr0.startsWith(QByteArray("moveTo"))) {
+    } else if (attr0.startsWith(QByteArrayLiteral("moveTo"))) {
         d->mBehaviour = MoveToCollection;
         d->mMoveToCollection = Akonadi::Collection(attr0.mid(6).toLongLong());
         // NOTE: 6 is the strlen of "moveTo".
